==> calamares-settings-solydxk_4.17%2Br13.tar.xz: source/ts/calamares-solydxk_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Obrigado por escolher o SolydXK&lt;/h3&gt;&lt;br /&gt;Você escolheu uma distribuição Linux que é:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Segura e estável&lt;/li&gt;&lt;li&gt;Rápida e responsiva&lt;/li&gt;&lt;li&gt;Pronta para uso pessoal&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Aproveite este novo lançamento e obrigado por escolher o SolydXK.&lt;br /&gt;&lt;br /&gt;A instalação demora 15-30 minutos, dependendo de suas configurações.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Situada sobre os ombros de gigantes&lt;/h3&gt;&lt;br /&gt;SolydXK é uma distribuição GNU/Linux baseada, derivada e compatível com o Debian.&lt;br /&gt;&lt;br /&gt;SolydXK usa tanto o levíssimo desktop Xfce para o SolydX ou o o altamente configurável e incrivelmente atraente desktop KDE para o SolydK.&lt;br /&gt;&lt;br /&gt;Nossas inovações, o rápido desenvolvimento do Debian e a quantidade enorme de pacotes Debian tornam o SolydXK um dos sistemas operacionais mais atraentes para desktop disponível para usuários domésticos.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Pronto para usar&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, e LibreOffice vem pré-instalados no SolydXK, para você poder começar a utilizar imediatamente seu computador e a Internet.&lt;br /&gt;&lt;br /&gt;Diferentemente de outras distribuições Linux o SolydXK também está pronto para tocar suas música, vídeos da internet e muito mais.&lt;br /&gt;&lt;br /&gt;Uma grande variedade de aplicativos podem ser instalados com um clique do mouse.&lt;br /&gt;&lt;br /&gt;O SolydXK é compatível com os formatos de arquivos mais populares como: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, e muito mais.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Ferramentas de escritório estão prontas para uso logo após a instalação do SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, uma suite de escritório poderosa acompanha o SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice é super fácil de aprender e usar.&lt;br /&gt;&lt;br /&gt;Você pode usá-lo para criar documentos, apresentações e planilhas, assim como diagramas e bancos de dados.&lt;br /&gt;&lt;br /&gt;LibreOffice usa o formato padrão OpenDocument e ele trabalha com documentos de outras aplicações de escritório mais populares, incluindo WordPerfect e Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.&lt;br /&gt;&lt;br /&gt;SolydXK can detect other operating systems and install itself beside them.You can choose which operating system to launch when you start the computer.</source>
        <translation>&lt;h3&gt;Uma alternativa aos sistemas operacionais mais conhecidos&lt;/h3&gt;&lt;br /&gt;O SolydXK é fácil de usar, poderoso e configurável.&lt;br /&gt;&lt;br /&gt;O SolydXK é seguro e estável. Ao contrário de outros sistemas operacionais, não é propenso a vírus de computador ou spyware, não sofre de fragmentação do disco, e não tem nenhum registro que requer limpeza periódica.&lt;br /&gt;&lt;br /&gt;O SolydXK pode detectar outros sistemas operacionais e ser instalado lado a lado com eles. Você pode escolher qual sistema operacional deseja iniciar quando ligar o computador.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="143"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Atualizações seguras&lt;/h3&gt;&lt;br /&gt;Alguns sistemas operacionais fazem a atualização de seu sistema mais difícil do que realmente precisa ser. O SolydXK acha que atualizações devem ser rápidas e fáceis, sem complicações.&lt;br /&gt;&lt;br /&gt;O Gerenciador de Atualizações localiza-se discretamente na bandeja do sistema e avisa quando há atualizações disponíveis. Você não precisa aplicar as atualizações quando você não quiser. O Gerenciador de Atualizações não irá aparecer ou incomodá-lo de maneira alguma.&lt;br /&gt;&lt;br /&gt;Todos os arquivos atualizados são mantidos e minuciosamente examinados por desenvolvedores e mantenedores de confiança.&lt;br /&gt;&lt;br /&gt;Todos os arquivos são armazenados em repositórios especiais seguros para o seu uso.&lt;br /&gt;&lt;br /&gt;O repositório de segurança é sincronizado diáriamente.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="165"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Uma grande comunidade.&lt;/h3&gt;&lt;br /&gt;Os utilizadores de SolydXK sentem-se bem em compartilhar a sua paixão e entusiasmo e estão ansiosos para o ajudar. Não hesite em fazer perguntas nos fóruns ou envolva-se na comunidade.&lt;br /&gt;&lt;br /&gt;Envie-nos os seus comentários e conte-nos sobre a sua experiência. Iremos ouvir as suas ideias e usá-las para melhorar ainda mais a SolydXK.</translation>
    </message>
</context>
</TS>

==> calamares-settings-solydxk_4.27%2Br13.tar.xz: source/ts/calamares-solydxk_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Obrigado por escolher o SolydXK&lt;/h3&gt;&lt;br /&gt;Você escolheu uma distribuição Linux que é:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Segura e estável&lt;/li&gt;&lt;li&gt;Rápida e responsiva&lt;/li&gt;&lt;li&gt;Pronta para uso pessoal&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Aproveite este novo lançamento e obrigado por escolher o SolydXK.&lt;br /&gt;&lt;br /&gt;A instalação demora 15-30 minutos, dependendo de suas configurações.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Situada sobre os ombros de gigantes&lt;/h3&gt;&lt;br /&gt;SolydXK é uma distribuição GNU/Linux baseada, derivada e compatível com o Debian.&lt;br /&gt;&lt;br /&gt;SolydXK usa tanto o levíssimo desktop Xfce para o SolydX ou o o altamente configurável e incrivelmente atraente desktop KDE para o SolydK.&lt;br /&gt;&lt;br /&gt;Nossas inovações, o rápido desenvolvimento do Debian e a quantidade enorme de pacotes Debian tornam o SolydXK um dos sistemas operacionais mais atraentes para desktop disponível para usuários domésticos.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Pronto para usar&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, e LibreOffice vem pré-instalados no SolydXK, para você poder começar a utilizar imediatamente seu computador e a Internet.&lt;br /&gt;&lt;br /&gt;Diferentemente de outras distribuições Linux o SolydXK também está pronto para tocar suas música, vídeos da internet e muito mais.&lt;br /&gt;&lt;br /&gt;Uma grande variedade de aplicativos podem ser instalados com um clique do mouse.&lt;br /&gt;&lt;br /&gt;O SolydXK é compatível com os formatos de arquivos mais populares como: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, e muito mais.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Ferramentas de escritório estão prontas para uso logo após a instalação do SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, uma suite de escritório poderosa acompanha o SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice é super fácil de aprender e usar.&lt;br /&gt;&lt;br /&gt;Você pode usá-lo para criar documentos, apresentações e planilhas, assim como diagramas e bancos de dados.&lt;br /&gt;&lt;br /&gt;LibreOffice usa o formato padrão OpenDocument e ele trabalha com documentos de outras aplicações de escritório mais populares, incluindo WordPerfect e Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.</source>
        <translation>&lt;h3&gt;Uma alternativa aos sistemas operativos convencionais&lt;/h3&gt;&lt;br /&gt;SolydXK é fácil de usar, poderoso e configurável.&lt;br /&gt;&lt;br /&gt;SolydXK é seguro e estável. Ao contrário de outros sistemas operativos, não é propenso a vírus ou spyware, ele não sofre de fragmentação do disco, e não tem nenhum registry que requeira uma limpeza periódica.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="142"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Atualizações seguras&lt;/h3&gt;&lt;br /&gt;Alguns sistemas operacionais fazem a atualização de seu sistema mais difícil do que realmente precisa ser. O SolydXK acha que atualizações devem ser rápidas e fáceis, sem complicações.&lt;br /&gt;&lt;br /&gt;O Gerenciador de Atualizações localiza-se discretamente na bandeja do sistema e avisa quando há atualizações disponíveis. Você não precisa aplicar as atualizações quando você não quiser. O Gerenciador de Atualizações não irá aparecer ou incomodá-lo de maneira alguma.&lt;br /&gt;&lt;br /&gt;Todos os arquivos atualizados são mantidos e minuciosamente examinados por desenvolvedores e mantenedores de confiança.&lt;br /&gt;&lt;br /&gt;Todos os arquivos são armazenados em repositórios especiais seguros para o seu uso.&lt;br /&gt;&lt;br /&gt;O repositório de segurança é sincronizado diáriamente.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="164"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Uma grande comunidade.&lt;/h3&gt;&lt;br /&gt;Os utilizadores de SolydXK sentem-se bem em compartilhar a sua paixão e entusiasmo e estão ansiosos para o ajudar. Não hesite em fazer perguntas nos fóruns ou envolva-se na comunidade.&lt;br /&gt;&lt;br /&gt;Envie-nos os seus comentários e conte-nos sobre a sua experiência. Iremos ouvir as suas ideias e usá-las para melhorar ainda mais a SolydXK.</translation>
    </message>
</context>
</TS>
